"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RedisService = void 0;
const uuid_1 = require("uuid");
class RedisService {
    constructor(client) {
        /** 分布式锁 key-value map */
        this.lockMap = new Map();
        this.client = client;
    }
    /**
     * 从Redis中取出数据
     * @param key 键
     */
    async get(key) {
        const data = await this.client.get(key);
        if (!data)
            return data;
        return new Promise(resolve => {
            try {
                const result = JSON.parse(data);
                resolve(result);
            }
            catch (error) {
                resolve(data);
            }
        });
    }
    /**
     * 向Redis中存储数据（无过期时间）
     * @param key 键
     * @param value 值
     * @returns 存储结果
     */
    async set(key, value) {
        const result = await this.client.set(key, value);
        return result === 'OK';
    }
    /**
     * 向Redis中存储数据（过期时间以秒计）
     * @param key 键
     * @param value 值
     * @param seconds 过期时间，单位：秒
     * @returns 存储结果
     */
    async setex(key, value, seconds) {
        const result = await this.client.setex(key, seconds, value);
        return result === 'OK';
    }
    /**
     * 向Redis中存储数据（过期时间以毫秒计）
     * @param key 键
     * @param value 值
     * @param milliseconds 过期时间，单位：毫秒
     * @returns 存储结果
     */
    async psetex(key, value, milliseconds) {
        const result = await this.client.psetex(key, milliseconds, value);
        return result === 'OK';
    }
    /**
     * 值自增
     * @param key 键
     * @returns 自增后的结果
     */
    async incr(key) {
        return this.client.incr(key);
    }
    /**
     * 往散列中存储键值对
     * @description 如果散列中没有这个字段，插入成功，返回true。如果有这个字段，插入失败，返回false
     * @param key 散列key
     * @param field 散列字段
     * @param value 散列字段值
     * @returns 存储结果
     */
    async hsetnx(key, field, value) {
        return !!(await this.client.hsetnx(key, field, value));
    }
    /**
     * 往散列中存储键值对（覆盖方式）
     * @param key 散列key
     * @param field 散列字段
     * @param value 散列字段值
     * @returns 存储结果
     */
    async hmset(key, field, value) {
        return !!(await this.client.hmset(key, field, value));
    }
    /**
     * 往散列中存储键值对（覆盖方式），支持过期时间
     * @param key 散列key
     * @param field 散列字段
     * @param value 散列字段值
     * @param seconds 过期时间，单位：秒
     * @returns 存储结果
     */
    async hmsetex(key, field, value, seconds) {
        const result = !!(await this.client.hmset(key, field, value));
        if (result)
            this.client.expire(`${key}:${field}`, seconds);
        return result;
    }
    /**
     * 获取散列中指定字段的数据
     * @param key 散列key
     * @param field 散列字段
     * @returns 散列中key所对应的数据
     */
    async hget(key, field) {
        const data = await this.client.hget(key, field);
        if (!data)
            return data;
        return new Promise(resolve => {
            try {
                const result = JSON.parse(data);
                resolve(result);
            }
            catch (error) {
                resolve(data);
            }
        });
    }
    /**
     * 获取散列数据
     * @param key 散列key
     * @returns 散列数据
     */
    async hgetall(key) {
        return this.client.hgetall(key);
    }
    /**
     * 从散列中删除键值对
     * @param key 散列key
     * @param field 散列字段
     * @returns 删除结果
     */
    async hdel(key, field) {
        return !!(await this.client.hdel(key, field));
    }
    /**
     * 往列表中插入元素
     * @param key 列表key
     * @param value 元素值
     * @returns 列表中节点数量
     */
    async rpush(key, value) {
        return this.client.rpush(key, value);
    }
    /**
     * 从Redis中取出List数据
     * @param key 键
     * @returns 列表数据
     */
    async getList(key) {
        const data = await this.client.lrange(key, 0, -1);
        return new Promise(resolve => {
            try {
                const result = data.map(i => JSON.parse(i));
                resolve(result);
            }
            catch (error) {
                resolve(data);
            }
        });
    }
    /**
     * 删除redis中的记录
     * @param key 要删除的key
     * @returns 删除结果
     */
    async delete(key) {
        return (await this.client.psetex(key, 1, '')) === 'OK';
    }
    /**
     * 设置键的过期时间
     * @param key 键
     * @param seconds 过期时间，单位：秒
     * @returns 设置成功与否
     */
    async expire(key, seconds) {
        return !!(await this.client.expire(key, seconds));
    }
    /**
     * 获取锁
     * @param lock 锁key
     * @param expire 过期时间，单位：毫秒
     * @returns 锁获取结果
     */
    async getLock(lock, expire) {
        const value = (0, uuid_1.v4)();
        const result = await this.client.set(lock, value, 'PX', expire, 'NX');
        if (result)
            this.lockMap.set(lock, value);
        return !!result;
    }
    /**
     * 释放锁
     * @param lock 锁key
     * @returns 释放结果
     */
    async releaseLock(lock) {
        if (this.lockMap.get(lock) !== (await this.client.get(lock)))
            return false;
        return !!(await this.client.psetex(lock, 1, this.lockMap.get(lock)));
    }
}
exports.RedisService = RedisService;
